from .utils_config import config_check, get_auth_config
from .apis import get_file_signed_url


@config_check
def get_file_url(filepath):
    api_token, workspace_id = get_auth_config()
    return get_file_signed_url(workspace_id, filepath, api_token)



import fire
from pathlib import Path

from .utils_config import get_auth_config, config_check, save_config
from .apis import upload_file


class CLI(object):

    def configure(self, api_token):
        save_config({'api_token': api_token})
        print("Done!")

    @config_check
    def upload(self, directory):
        api_token, workspace_id = get_auth_config()
        if workspace_id is None:
            return print("Bad API token")

        files = [path for path in Path(directory).rglob('*') if path.is_file()]
        for path in files:
            filename = path.as_posix().removeprefix(directory)
            ok = upload_file(workspace_id, filename,
                             path.open("rb"), api_token)
            if not ok:
                print(f"Error uploading file {filename}")
                return False
            else:
                print(f"Uploaded file {filename}")


def main():
    fire.Fire(CLI)



import json
import requests
import urllib.request
import urllib.response


def upload_file(workspace_id, filepath, file, api_token):
    response = requests.post(
        f"https://hackerforms-api.abstra.cloud/workspaces/{workspace_id}/put-url",
        data=json.dumps({'filepath': filepath}),
        headers={'content-type': 'application/json',
                 'API-Authorization': api_token}
    )
    response_json = response.json()
    req = urllib.request.Request(
        url=response_json["putURL"],
        method='PUT',
        data=file.read())
    res = urllib.request.urlopen(req)
    return res.status < 400


def get_file_signed_url(workspace_id, filepath, api_token):
    response = requests.post(
        f"https://hackerforms-api.abstra.cloud/workspaces/{workspace_id}/get-url",
        data=json.dumps({'filepath': filepath}),
        headers={'content-type': 'application/json',
                 'API-Authorization': api_token}
    )
    response_json = response.json()
    return response_json.get("getURL")


def get_workspace_from_token(api_token):
    response = requests.post(
        f"https://auth.abstra.cloud/abstra-cloud",
        data=json.dumps({'headers': {'API-Authorization': api_token}}),
        headers={'content-type': 'application/json'}
    )
    response_json = response.json()
    workspaces = response_json.get('workspaces', [{}])
    if len(workspaces) == 0:
        return None
    return workspaces[0].get('id')



import os
import json

from .utils import create_abstra_dir
from .apis import get_workspace_from_token


def save_config(data):
    if isinstance(data, dict):
        data = json.dumps(data)
    path = create_abstra_dir() + "/config.json"
    with open(path, "w") as f:
        f.write(data)


def read_config():
    path = create_abstra_dir() + "/config.json"

    if not os.path.exists(path):
        return {}

    with open(path) as f:
        return json.load(f)


def get_api_token():
    return os.getenv('ABSTRA_API_TOKEN') or read_config().get('api_token')


def get_auth_config():
    api_token = get_api_token()
    workspace_id = get_workspace_from_token(api_token)
    return api_token, workspace_id


def config_check(f):
    def wrapper(*args):
        if not get_api_token():
            raise Exception("No API token configured")
        return f(*args)
    return wrapper



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name='abstra-cli',
    version='0.2.0',
    description='Abstra CLI',
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/abstra-app/abstra-cli",
    license='MIT',
    packages=['abstra_cli'],
    install_requires=['setuptools', 'requests',
                      'fire', 'simple_websocket_server'],
    entry_points={
        'console_scripts': [
            'abstra-cli=abstra_cli.cli:main',
        ],
    },
)



import os


def create_abstra_dir():
    path = rebase_path('/.abstra')
    if not os.path.exists(path):
        os.makedirs(path)
    return path


def rebase_path(path="/"):
    return os.path.expanduser("~" + path)
